@@ -12,6 +12,6 @@ class RecaptchaField(Field):
     # error message if recaptcha validation fails
     recaptcha_error = None
 
-    def __init__(self, label='', validators=None, **kwargs):
+    def __init__(self, label="", validators=None, **kwargs):
         validators = validators or [Recaptcha()]
-        super(RecaptchaField, self).__init__(label, validators, **kwargs)
+        super().__init__(label, validators, **kwargs)
